columns_with_headers.pdf

## Metadata

Title | columns_with_headers.pdf
Path | C:\Users\jenni\OneDrive\Documents\Code\burdoc\burdoc\tests\integration\data\inputs\columns_with_headers.pdf
Pages | 0
PDF Metadata: format | PDF 1.7
PDF Metadata: title |
PDF Metadata: author | Joe Ennis
PDF Metadata: subject |
PDF Metadata: keywords |
PDF Metadata: creator | Microsoft® Word for Microsoft 365
PDF Metadata: producer | Microsoft® Word for Microsoft 365
PDF Metadata: creationDate | D:20230403055427+01'00'
PDF Metadata: modDate | D:20230403055427+01'00'
PDF Metadata: trapped |
PDF Metadata: encryption |

## Contents

1. Page 0
2. h1 :: Est Quis quasi aut iure esse.
3. h6 :: Lorem ipsum dolor sit amet. Et quam illo
4. h3 :: Vel delectus officia ut consequuntur similique ut suscipit vero.
5. h6 :: Cum soluta iste ad nulla omnis.

#### Page 0

No images

Path: | content.0.[0,0].bbox
Type: | addition

Key | Old | New
x1 |  | 265.5119934082031
y1 |  | 127.96902465820312
y0 |  | 75.14779663085938
x0 |  | 72.02400207519531

Path: | content.0.[1,1].bbox
Type: | addition

Key | Old | New
x1 |  | 273.6840515136719
y1 |  | 154.94772338867188
y0 |  | 142.94772338867188
x0 |  | 72.02400207519531

Path: | content.0.[2,2].bbox
Type: | addition

Key | Old | New
x1 |  | 264.92401123046875
y1 |  | 320.5777282714844
y0 |  | 156.74771118164062
x0 |  | 72.02400207519531

Path: | content.0.[3,3].bbox
Type: | addition

Key | Old | New
x1 |  | 277.6199951171875
y1 |  | 397.24176025390625
y0 |  | 337.84173583984375
x0 |  | 72.02400207519531

Path: | content.0.[4,4].bbox
Type: | addition

Key | Old | New
x1 |  | 235.6680145263672
y1 |  | 438.32354736328125
y0 |  | 412.3977355957031
x0 |  | 72.02400207519531

Path: | content.0.[5,5].bbox
Type: | addition

Key | Old | New
x1 |  | 281.85601806640625
y1 |  | 576.2276611328125
y0 |  | 439.9977111816406
x0 |  | 72.02400207519531

Path: | content.0.[6,6].bbox
Type: | addition

Key | Old | New
x1 |  | 244.15467834472656
y1 |  | 621.798583984375
y0 |  | 592.7586059570312
x0 |  | 72.02400207519531

Path: | content.0.[7,7].bbox
Type: | addition

Key | Old | New
x1 |  | 281.85601806640625
y1 |  | 690.4677124023438
y0 |  | 637.0676879882812
x0 |  | 72.02400207519531

Path: | content.0.[8,8].bbox
Type: | addition

Key | Old | New
x1 |  | 262.9700012207031
y1 |  | 718.1935424804688
y0 |  | 692.3935546875
x0 |  | 72.02400207519531

Path: | content.0.[9,9].bbox
Type: | addition

Key | Old | New
x1 |  | 274.9920349121094
y1 |  | 759.4876708984375
y0 |  | 719.8876953125
x0 |  | 72.02400207519531

Path: | content.0.[10,10].bbox
Type: | addition

Key | Old | New
x1 |  | 518.385986328125
y1 |  | 127.1076889038086
y0 |  | 73.70773315429688
x0 |  | 315.42999267578125

Path: | content.0.[11,11].bbox
Type: | addition

Key | Old | New
x1 |  | 482.260009765625
y1 |  | 155.37449645996094
y0 |  | 143.37449645996094
x0 |  | 315.42999267578125

Path: | content.0.[12,12].bbox
Type: | addition

Key | Old | New
x1 |  | 517.1919555664062
y1 |  | 196.89451599121094
y0 |  | 170.66769409179688
x0 |  | 315.42999267578125

Path: | content.0.[13,13].bbox
Type: | addition

Key | Old | New
x1 |  | 523.1859741210938
y1 |  | 362.09771728515625
y0 |  | 198.26773071289062
x0 |  | 315.42999267578125

Path: | content.0.[14,14].bbox
Type: | addition

Key | Old | New
x1 |  | 504.9435729980469
y1 |  | 403.989990234375
y0 |  | 378.40997314453125
x0 |  | 315.42999267578125

Path: | content.0.[15,15].bbox
Type: | addition

Key | Old | New
x1 |  | 509.302001953125
y1 |  | 488.2435607910156
y0 |  | 420.917724609375
x0 |  | 315.42999267578125

Path: | content.0.[16,16].bbox
Type: | addition

Key | Old | New
x1 |  | 517.4860229492188
y1 |  | 515.843505859375
y0 |  | 490.0435485839844
x0 |  | 315.42999267578125

Path: | content.0.[17,17].bbox
Type: | addition

Key | Old | New
x1 |  | 524.4099731445312
y1 |  | 557.5444946289062
y0 |  | 517.5177001953125
x0 |  | 315.42999267578125

Path: | content.0.[18,18].bbox
Type: | addition

Key | Old | New
x1 |  | 525.5800170898438
y1 |  | 653.7476806640625
y0 |  | 558.9476928710938
x0 |  | 315.42999267578125

Path: | content.0.[19,19].bbox
Type: | addition

Key | Old | New
x1 |  | 525.5859985351562
y1 |  | 764.2877197265625
y0 |  | 669.4677124023438
x0 |  | 315.42999267578125

# Est Quis quasi aut iure esse.

###### Lorem ipsum dolor sit amet. Et quam illo

Quo fugiat eum sint voluptates? Qui suscipit voluptatemEa architecto ut molestiae expedita est galisum laborum qui Quis necessitatibus ut impedit reprehenderit aut molestiae accusamus. Quo quia voluptate sit saepe sequisit eligendi et omnis nostrum et impedit dolores. Eum voluptates aperiam id voluptas assumendaet necessitatibus id sequi neque. Et voluptatem maxime est voluptatem quosest illum non vero laudantium?

### Vel delectus officia ut consequuntur similique ut suscipit vero.

Non voluptas dicta ut perspiciatis asperiores Ea dolore nam eaque

praesentium. Aut ratione ducimusIn voluptatibus quo autem iste quo enim facere est iste voluptas ea rerum assumenda sit repellat nihil. Ea dolor doloribus qui soluta iustoaut similique. Sit saepe rerum ut iusto maximeest dolor aut pariatur molestiae. Eos delectus corporisUt perferendis et consectetur praesentium qui quia vero in itaque Quis ut illum numquam.

Ea excepturi eveniet qui alias rerum id facere error.

Qui eligendi eaque ex enim commodiea neque! Est magnam voluptas est tempora temporibusnon provident sit quae alias non veritatis laudantium. Non nesciunt earum

Non nulla eum impedit dolorum et esse maxime aut libero voluptatem hic

obcaecati optio a laboriosam sint. Aut cupiditate internos ea cumque praesentiumeum itaque qui sequi ipsa. Sit

debitis voluptas33 quos ea nobis galisum. Et facere debitisquo velit est tempora voluptate. Sed quaerat exercitationemet tempore est fugit quia?

###### Cum soluta iste ad nulla omnis.

Sed dolorum rerum sit adipisci fugiat Est obcaecati. Aut galisum architectoNon

aperiam qui provident consequuntur qui nemo nihil in galisum dolore et fugiat explicabo! Aut neque amet qui nemo assumendaAut praesentium id voluptas ipsum qui illum ratione et molestiae laudantium 33 magni eligendi. Et internos consequatur ut voluptatibus culpa33 repellat quo voluptatem quam rem cupiditate maiores. Aut illo quisquam et officia voluptatemEt autem et minus perferendis nam laudantium facere ut fugit similique?

Et fugiat sapiente aut sapiente suscipit aut rerum rerum.

Sit odit aliquam et molestiae praesentiumrem ducimus cum soluta soluta. At tempora saepe ut architecto temporaaut voluptate. Ex saepe mollitia eos voluptatem consequatur Aut

consequatur aut debitis sunt et atque rerum qui quasi totam. Ut nobis minusEa

earum qui quia vero est sint iste eum quam harum sed voluptate dicta. Ex enim quos At optio iure Sit facere ut ratione

praesentium aut pariatur reprehenderit. Quo debitis maiores ut quis ducimusAut internos aut suscipit sapiente a maxime dicta ea dolorem illum vel illo mollitia. Est velit incidunt in nostrum nobisAb quisquam est iure fugit id velit quia sit atque nobis id itaque sunt.

Est velit nequeIn animi id temporibus atque est dolor debitis. Aut magnam dignissimos aut debitis aliquamA harum At nostrum deserunt nam enim veritatis in delectus velit ut consequatur molestiae. Est eligendi laudantium vel maiores dolores33 maxime quo aliquid beatae ea eligendi

# Est Quis quasi aut iure esse.

###### Lorem ipsum dolor sit amet. Et quam illo

Quo fugiat eum sint voluptates? Qui suscipit voluptatemEa architecto ut molestiae expedita est galisum laborum qui Quis necessitatibus ut impedit reprehenderit aut molestiae accusamus. Quo quia voluptate sit saepe sequisit eligendi et omnis nostrum et impedit dolores. Eum voluptates aperiam id voluptas assumendaet necessitatibus id sequi neque. Et voluptatem maxime est voluptatem quosest illum non vero laudantium?

### Vel delectus officia ut consequuntur similique ut suscipit vero.

Non voluptas dicta ut perspiciatis asperiores Ea dolore nam eaque

praesentium. Aut ratione ducimusIn voluptatibus quo autem iste quo enim facere est iste voluptas ea rerum assumenda sit repellat nihil. Ea dolor doloribus qui soluta iustoaut similique. Sit saepe rerum ut iusto maximeest dolor aut pariatur molestiae. Eos delectus corporisUt perferendis et consectetur praesentium qui quia vero in itaque Quis ut illum numquam.

Ea excepturi eveniet qui alias rerum id facere error.

Qui eligendi eaque ex enim commodiea neque! Est magnam voluptas est tempora temporibusnon provident sit quae alias non veritatis laudantium. Non nesciunt earum

Non nulla eum impedit dolorum et esse maxime aut libero voluptatem hic

obcaecati optio a laboriosam sint. Aut cupiditate internos ea cumque praesentiumeum itaque qui sequi ipsa. Sit

debitis voluptas33 quos ea nobis galisum. Et facere debitisquo velit est tempora voluptate. Sed quaerat exercitationemet tempore est fugit quia?

###### Cum soluta iste ad nulla omnis.

Sed dolorum rerum sit adipisci fugiat Est obcaecati. Aut galisum architectoNon

aperiam qui provident consequuntur qui nemo nihil in galisum dolore et fugiat explicabo! Aut neque amet qui nemo assumendaAut praesentium id voluptas ipsum qui illum ratione et molestiae laudantium 33 magni eligendi. Et internos consequatur ut voluptatibus culpa33 repellat quo voluptatem quam rem cupiditate maiores. Aut illo quisquam et officia voluptatemEt autem et minus perferendis nam laudantium facere ut fugit similique?

Et fugiat sapiente aut sapiente suscipit aut rerum rerum.

Sit odit aliquam et molestiae praesentiumrem ducimus cum soluta soluta. At tempora saepe ut architecto temporaaut voluptate. Ex saepe mollitia eos voluptatem consequatur Aut

consequatur aut debitis sunt et atque rerum qui quasi totam. Ut nobis minusEa

earum qui quia vero est sint iste eum quam harum sed voluptate dicta. Ex enim quos At optio iure Sit facere ut ratione

praesentium aut pariatur reprehenderit. Quo debitis maiores ut quis ducimusAut internos aut suscipit sapiente a maxime dicta ea dolorem illum vel illo mollitia. Est velit incidunt in nostrum nobisAb quisquam est iure fugit id velit quia sit atque nobis id itaque sunt.

Est velit nequeIn animi id temporibus atque est dolor debitis. Aut magnam dignissimos aut debitis aliquamA harum At nostrum deserunt nam enim veritatis in delectus velit ut consequatur molestiae. Est eligendi laudantium vel maiores dolores33 maxime quo aliquid beatae ea eligendi

Parent File Contents